<?php

/**
 * @package    WPBuddy Plugin
 * @subpackage Google+ Drive CDN
 */

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


/**
 * Echoes out the Metabox contents
 * @since 1.0
 */
class WPB_Google_Drive_Cdn_Metaboxes {

	/**
	 * @var null|WPB_Google_Drive_Cdn
	 */
	private $_google_drive_cdn = null;


	/**
	 * @param WPB_Google_Drive_Cdn $google_drive_cdn
	 *
	 * @since    1.0
	 * @return \WPB_Google_Drive_Cdn_Metaboxes
	 */
	public function __construct( &$google_drive_cdn ) {
		$this->_google_drive_cdn = $google_drive_cdn;
	}


	/**
	 * creates the content for the enabling_api metabox
	 * shows some information on the plugin
	 *
	 * @access public
	 *
	 * @return void
	 * @since 1.0
	 */
	public function enabling_api() {

		echo '<p>', __( 'First, you need to enable the Drive API for the plugin. You can do this in your app\'s API project in the Google APIs Console.', $this->_google_drive_cdn->get_textdomain() ), '</p>';

		echo '<ol>';
		echo '<li>', sprintf( __( 'You need a Google account. You do not have a Google account? Click here to create one: %s', $this->_google_drive_cdn->get_textdomain() ), '<a href="https://www.google.com/accounts/NewAccount" target="_blank">https://www.google.com/accounts/NewAccount</a>' ), '</li>';
		echo '<li>', sprintf( __( 'Create an API project in the Google APIs Console by following this link: %s', $this->_google_drive_cdn->get_textdomain() ), '<a href="https://code.google.com/apis/console/" target="_blank">https://code.google.com/apis/console/</a>' );
		echo '<ol>';
		echo '<li>', __( 'Click on the big blue button which says "Create project...".', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'OR if you already have some running projects, click on the dropdown to your left, choose "Create..." and type in a name (ex. "WordPress to Google Drive").', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '</ol></li>';
		echo '<li>', __( 'If done click "Services".', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'Activate the "Drive API" and "Drive SDK" (set the switch to ON).', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'On the menu click "API Access".', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'Click on the big blue button which says "Create an OAuth 2.0 client ID...".', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'Choose a product name (ex. "WordPress to Google Drive CDN").', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'Optional: Choose a picture.', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', sprintf( __( 'Enter %s in the field "Home Page URL"', $this->_google_drive_cdn->get_textdomain() ), '<strong>' . home_url() . '</strong>' ), '</li>';
		echo '<li>', __( 'Click "Next".', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'On the next screen, choose <strong>"Web application"</strong>', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', sprintf( __( 'Enter %s in the "Your site or hostname" field', $this->_google_drive_cdn->get_textdomain() ), '<strong>' . str_replace( 'http://', '', str_replace( 'https://', '', admin_url( 'options-general.php?page=wpbgdc' ) ) ) . '</strong>' ), '</li>';
		echo '<li>', sprintf( __( 'Choose %s from the dropdown.', $this->_google_drive_cdn->get_textdomain() ), '<strong>' . ( ( is_ssl() ) ? 'https://' : 'http://' ) . '</strong>' ), '</li>';
		echo '<li>', __( 'Click "Create Client ID".', $this->_google_drive_cdn->get_textdomain() ), '</li>';
		echo '<li>', __( 'Enter the Client ID and the Client Secret from the "Client ID for web applications" section into the fields below:', $this->_google_drive_cdn->get_textdomain() ), '</li>';

		echo '</ol>';

		echo '<table class="form-table">';
		do_settings_fields( 'wpbgdc', 'wpbgdc_section_client_credentials' );
		echo '</table>';

		submit_button( null, 'primary', 'submit', false ); //no wrapping

	}


	/**
	 * creates the content for the howto-metabox
	 *
	 * @access public
	 *
	 * @return void
	 * @since 1.0
	 */
	public function connect() {

		$helper = new WPB_Google_Drive_Cdn_Service_Helper( $this->_google_drive_cdn );

		$is_api_working = $helper->is_api_working();

		$client = $this->_google_drive_cdn->get_google_client();
		$client->setState( 'got_code' );
		$client->setAccessType( 'offline' );

		echo '<p>' . __( 'Please note: you will be redirected to a Google\'s authorization page. Please press the blue button to give this application the right to upload files.', $this->_google_drive_cdn->get_textdomain() ) . '</p>';

		echo '<a class="button-primary" href="' . $client->createAuthUrl() . '">' . __( 'Grant writing permissions to your Google Drive', $this->_google_drive_cdn->get_textdomain() ) . '</a>';

		if( ! $is_api_working ) {
			echo '<div class="error"><p>', __( 'The Google Drive API is currently not working.', $this->_google_drive_cdn->get_textdomain() ), ' ' . __( 'Try to (re-)authenticate by using the button "Grant writing permissions to your Google Drive" button.', $this->_google_drive_cdn->get_textdomain() ), '</p></div>';
		}

	}


	/**
	 * creates the content for the settings metabox
	 *
	 * @access public
	 *
	 * @return void
	 * @since 1.0
	 */
	public function settings() {

		do_settings_sections( 'wpbgdc' );

		submit_button();

		echo '<div class="clear"></div>';

	}

	/**
	 * The "about" metabox
	 * @since 1.0
	 * @return void
	 */
	public function about() {
		?><a href="http://bit.ly/TO0Z5w" target="_blank"><img src="https://wpbuddy.libra.uberspace.de/secure/wp-buddy-logo.png" alt="WPBuddy Logo" /></a><?php
	}


	/**
	 * Outputs the metabox content for the links
	 * @since 1.0
	 * @return void
	 */
	public function links() {
		?>
		<ul>
			<li><a href="http://bit.ly/15uoww1" target="_blank"><?php echo __( 'Installation manual', $this->_google_drive_cdn->get_textdomain() ); ?></a></li>
			<li><a href="http://bit.ly/W9GDQT" target="_blank"><?php echo __( 'Frequently Asked Questions', $this->_google_drive_cdn->get_textdomain() ); ?></a></li>
			<li><a href="http://bit.ly/WW93Sk" target="_blank"><?php echo __( 'Report a bug', $this->_google_drive_cdn->get_textdomain() ); ?></a></li>
			<li><a href="http://bit.ly/11UE2lF" target="_blank"><?php echo __( 'Request a function', $this->_google_drive_cdn->get_textdomain() ); ?></a></li>
			<li><a href="http://bit.ly/XkivOW" target="_blank"><?php echo __( 'Submit a translation', $this->_google_drive_cdn->get_textdomain() ); ?></a></li>
			<li><a href="http://bit.ly/UlDG4t" target="_blank"><?php echo __( 'More cool stuff by WPBuddy', $this->_google_drive_cdn->get_textdomain() ); ?></a></li>
		</ul>
	<?php
	}


	/**
	 * Outputs the metabox content for the social links
	 * @return void
	 * @since 1.0
	 */
	public function social() {
		?>
		<p>

		<div class="g-plusone" data-size="medium" data-href="http://wp-buddy.com/products/plugins/google-drive-as-wordpress-cdn-plugin/"></div>
		</p>

		<script type="text/javascript">
			(function() {
				var po = document.createElement( 'script' );
				po.type = 'text/javascript';
				po.async = true;
				po.src = 'https://apis.google.com/js/plusone.js';
				var s = document.getElementsByTagName( 'script' )[0];
				s.parentNode.insertBefore( po, s );
			})();
		</script>

		<p>
			<a href="https://twitter.com/share" class="twitter-share-button" data-url="http://wp-buddy.com/products/plugins/google-drive-as-wordpress-cdn-plugin/" data-text="Check out the Google Drive as CDN WordPress Plugin" data-related="wp_buddy">Tweet</a>
		</p>
		<script>!function( d, s, id ) {
				var js, fjs = d.getElementsByTagName( s )[0];
				if( !d.getElementById( id ) ) {
					js = d.createElement( s );
					js.id = id;
					js.src = "//platform.twitter.com/widgets.js";
					fjs.parentNode.insertBefore( js, fjs );
				}
			}( document, "script", "twitter-wjs" );</script>

		<p>
			<iframe src="//www.facebook.com/plugins/like.php?href=<?php echo urlencode( 'http://wp-buddy.com/products/plugins/google-drive-as-wordpress-cdn-plugin/' ); ?>&amp;send=false&amp;layout=button_count&amp;width=150&amp;show_faces=false&amp;font&amp;colorscheme=light&amp;action=like&amp;height=21" scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:150px; height:21px;" allowTransparency="true"></iframe>
		</p>
	<?php
	}


	/**
	 * Outputs the metabox content for the subscription
	 * @since 1.0
	 * @return void
	 */
	public function subscribe() {
		global $current_user;
		get_currentuserinfo();
		$name = $current_user->user_firstname;
		if( empty( $name ) ) $name = $current_user->display_name;
		?>
		<div class="wpbuddy-cr-form">
			<label style="width: 110px; display: inline-block;" for="text1210658"><?php echo __( 'Your first name', $this->_google_drive_cdn->get_textdomain() ); ?></label>
			<input style="width: 140px;" id="text1210658" name="209681" type="text" value="<?php echo $name; ?>" />
			<label style="width: 110px; display: inline-block;" for="text1210692"><?php echo __( 'Your E-Mail address', $this->_google_drive_cdn->get_textdomain() ); ?></label>
			<input style="width: 140px;" id="text1210692" name="email" value="<?php echo $current_user->user_email; ?>" type="text" />
			<a href="#" class="button button-primary"><?php echo __( 'Subscribe', $this->_google_drive_cdn->get_textdomain() ); ?></a>
		</div>
		<script type="text/javascript">
			//<![CDATA[

			jQuery( document ).ready( function() {
				/** Subscribe form **/
				jQuery( '.wpbuddy-cr-form a.button' ).click( function( e ) {
					e.preventDefault();

					var name = jQuery( '#text1210658' ).val();
					var mail = jQuery( '#text1210692' ).val();

					jQuery( [
						'<form style="display:none;" action="https://10955.cleverreach.com/f/54067/wcs/" method="post" target="_blank">',
						'<input id="text1210692" name="email" value="' + mail + '" type="text"  />',
						'<input id="text1210658" name="209681" type="text" value="' + name + '"  />',
						'</form>'
					].join( '' ) ).appendTo( 'body' )[0];

				} );
			} );
			/* ]]> */
		</script>
	<?php
	}


	/**
	 * Outputs the metabox content for the information
	 * @return void
	 * @since 1.0
	 */
	public function info() {
		$folder_name = WPB_Google_Drive_Cdn_Settings::get_setting( 'folder_name', 'wpbgdc_folders' );
		$folder_link = WPB_Google_Drive_Cdn_Settings::get_setting( 'folder_link', 'wpbgdc_folders' );

		echo '<p><strong>', sprintf(
			__( 'You are now ready to go! The plugin has created a folder named %1$s on your Google Drive. Click here to view all files: %2$s', $this->_google_drive_cdn->get_textdomain() ),
			$folder_name,
			'<a href="' . $folder_link . '" target="_blank">' . $folder_link . '</a>'
		), '</strong></p>';

		echo '<p>', __( 'The plugin works like this:', $this->_google_drive_cdn->get_textdomain() ), '</p>';

		echo '<ol>';
		echo '<li>' . __( 'If anyone visits a page of your website, the plugin searches for files that can be uploaded to Google Drive.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '<li>' . __( 'If the file is not yet uploaded to Google Drive the plugin will put it down into the cache-database for a later upload.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '<li>' . __( 'Every hour the plugin reads all these entries from the cache-database to sync files to your Google Drive that have not yet been synced.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '<li>' . __( 'Synced files can then be served directly from your Google Drive.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '<li>' . __( 'You can manually start syncing the files that have been written to the cache-database by clicking the "Sync local CDN"-button.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '<li>' . __( 'From time to time every single file gets located and uploaded to Google Drive. Because of this process the speed of your website should improve continuously.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '</ol>';

		echo '<p>', __( 'Please note:', $this->_google_drive_cdn->get_textdomain() ), '</p>';
		echo '<ol>';
		echo '<li>' . __( 'It is recommended to use a "caching plugin" like WP-Super-Cache to significantly improve page load time.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '<li>' . __( 'You can start sync your local media library to Google Drive using the "Sync my media library now"-button. Depending on the size of your media library this will take some time.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '<li>' . __( 'This plugin syncs new or updated files every hour. This can cause problems if you\'re using a WordPress theme which changed files on the file system. Try to manually sync files after changing any theme-related things.', $this->_google_drive_cdn->get_textdomain() ) . '</li>';
		echo '</ol>';

	}


	/**
	 * Outputs the metabox content for the settings
	 * @since 1.0
	 * @return void
	 */
	public function settings_section() {
		echo '<table class="form-table">';
		do_settings_fields( 'wpbgdc', 'wpbgdc_section_settings' );
		echo '</table>';

		submit_button( null, 'primary', 'submit', false ); //no wrapping
		echo ' <a class="button" href="' . admin_url( 'options-general.php?page=wpbgdc&action=disconnect&wpbgdc_nonce=' . wp_create_nonce( 'wpbgdc_disconnect' ) ) . '">' . __( 'Disconnect', $this->_google_drive_cdn->get_textdomain() ) . '</a>';
		echo ' <a class="button" href="' . admin_url( 'options-general.php?page=wpbgdc&action=clearcache&wpbgdc_nonce=' . wp_create_nonce( 'wpbgdc_clearcache' ) ) . '">' . __( 'Clear local CDN cache', $this->_google_drive_cdn->get_textdomain() ) . '</a>';
		echo ' <a class="button" href="' . admin_url( 'options-general.php?page=wpbgdc&action=empty_google_drive&wpbgdc_nonce=' . wp_create_nonce( 'wpbgdc_empty_google_drive' ) ) . '">' . __( 'Move all cached files to the Google Drive trash', $this->_google_drive_cdn->get_textdomain() ) . '</a>';
		echo ' <a class="button" href="' . admin_url( 'options-general.php?page=wpbgdc&action=start_sync&wpbgdc_nonce=' . wp_create_nonce( 'wpbgdc_start_sanc' ) ) . '">' . __( 'Sync local CDN', $this->_google_drive_cdn->get_textdomain() ) . '</a>';
		echo ' <a id="wpbgdc_sync_button" class="button" href="' . admin_url( 'admin-ajax.php' ) . '">' . __( 'Sync my media library now', $this->_google_drive_cdn->get_textdomain() ) . '</a>';
		echo ' <span id="wpbgdc_sync_processed" style="display:none; margin-left: 1em;">0%</span>';
		echo ' <img src="' . $this->_google_drive_cdn->plugins_url( 'assets/img/ajax-loader.gif' ) . '" id="wpbgdc_ajax_loader" style="display:none; vertical-align:middle;" />';
		?>
		<script type="text/javascript">
			//<![CDATA[

			var sync_running = false;

			function wbpgdc_ajax_start(){
				jQuery( '#wpbgdc_ajax_loader' ).show();
			}

			function wbpgdc_ajax_stop(){
				jQuery( '#wpbgdc_ajax_loader' ).hide();
			}

			function do_sync( next ) {
				jQuery.ajax('<?php echo admin_url( 'admin-ajax.php?action=wpbgdc_sync&start=' ); ?>' + next, {
					'type'      : 'GET',
					'dataType'  : 'json',
					'beforeSend': wbpgdc_ajax_start(),
					'complete'  : wbpgdc_ajax_stop(),
					'success'   : function (data) {
						sync_running = true;
						if( data.error == 0 ) {
							jQuery( '#wpbgdc_sync_processed' ).text( data.uploaded_total + '%' );
							if( data.next <= data.number_of_attachments ) {
								do_sync( data.next );
							}
							else {
								sync_running = false;
								jQuery( '#wpbgdc_sync_processed' ).fadeOut( 2000, function() {
									jQuery( this ).text( '0%' );
								} );
							}
						}
					}
				});
			}

			jQuery( document ).ready( function() {
				jQuery( '#wpbgdc_sync_button' ).click( function( e ) {
					e.preventDefault();
					jQuery( '#wpbgdc_sync_processed' ).show();
					if( !sync_running ) do_sync( 0 );
				} );
			} );
			/* ]]> */
		</script>
	<?php
	}


	/**
	 * Shows the  metabox for the error logs
	 * @since 1.1
	 */
	public function error_logs() {
		$errors = get_option( 'wpbgdc_error_log', array() );
		if( ! is_array( $errors ) ) return;
		krsort( $errors );
		foreach( $errors as $error ) {
			echo $error . '<br />';
		}
		echo ' <a class="button" href="' . admin_url( 'options-general.php?page=wpbgdc&action=delete_error_logs&wpbgdc_nonce=' . wp_create_nonce( 'wpbgdc_delete_error_logs' ) ) . '">' . __( 'Delete Logs', $this->_google_drive_cdn->get_textdomain() ) . '</a>';
	}


}